# Table of Contents

- [retrieving-fact-sheets](<./retrieving-fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Retrieving Fact Sheets (GraphQL)](<./Retrieving-Fact-Sheets-GraphQL.md>)
  - [Retrieving a Fact Sheet by ID](<./Retrieving-Fact-Sheets-GraphQL/Retrieving-a-Fact-Sheet-by-ID.md>)
  - [Retrieving All Fact Sheets](<./Retrieving-Fact-Sheets-GraphQL/Retrieving-All-Fact-Sheets.md>)
  - [Retrieving Custom Fact Sheet Attributes](<./Retrieving-Fact-Sheets-GraphQL/Retrieving-Custom-Fact-Sheet-Attributes.md>)
  - [Retrieving Related Fact Sheets](<./Retrieving-Fact-Sheets-GraphQL/Retrieving-Related-Fact-Sheets.md>)
